/*
** LOGIN.H
**
**      This header file contains the public HTTP interfaces used by the
**		Sambar Server for interfacing with User Login/Logout/Profile
**		Management.
**
**		Confidential Property of Tod Sambar
**		(c) Copyright Tod Sambar 1996-1997
**		All rights reserved.
**
**
** History:
** Chg#	Date	Description												Resp
** ----	-------	-------------------------------------------------------	----
**		27JAN97	Created													sambar
**		25MAR97	Added FTP support										sambar
*/

#if     !defined(__LOGIN_H__)
#define __LOGIN_H__

#include	<sambar.h>

/*
** Login/Logout/Profile Management Defines
*/
#define LOGIN_PROFILE_KEY		"Profile"

/*
** User Profile Structure
*/
typedef struct	login__profile
{
	SA_CHAR		name[SA_MAX_NAME + 1];
	SA_CHAR		group[SA_MAX_NAME + 1];
	SA_CHAR		username[SA_MAX_NAME + 1];

} LOGIN_PROFILE;


/*
** Sambar Server/User Login/Logout/Profile DLL Function Prototypes
*/
#if defined(__cplusplus)
extern "C" {
#endif /* defined(__cplusplus) */

extern SA_RETCODE SA_EXPORT		login_init(SA_CTX *sactx);

extern SA_RETCODE SA_EXPORT		user_login(SA_CTX *sactx, SA_CONN *saconn,
									SA_CHAR *username, SA_INT usernamelen,
									SA_CHAR *password, SA_INT passwordlen,
									SA_INT *infop);

extern SA_RETCODE SA_EXPORT		user_logout(SA_CTX *sactx, SA_CONN *saconn);

extern SA_RETCODE SA_EXPORT		user_profile(SA_CTX *sactx, SA_CONN *saconn,
									SA_CHAR *buffer, SA_INT buflen,
									SA_CHAR *data);

/*
** User Management
*/
extern SA_RETCODE SA_PUBLIC		user_add(SA_CTX *sactx, SA_CONN *saconn,
									SA_PARAMS *saparams, SA_INT *infop);
extern SA_RETCODE SA_PUBLIC		user_delete(SA_CTX *sactx, SA_CONN *saconn,
									SA_PARAMS *saparams, SA_INT *infop);
extern SA_RETCODE SA_PUBLIC		user_update(SA_CTX *sactx, SA_CONN *saconn,
									SA_PARAMS *saparams, SA_INT *infop);
extern SA_RETCODE SA_PUBLIC		user_list(SA_CTX *sactx, SA_CONN *saconn,
									SA_PARAMS *saparams, SA_INT *infop);
extern SA_RETCODE SA_PUBLIC		user_select(SA_CTX *sactx, SA_CONN *saconn,
									SA_PARAMS *saparams, SA_INT *infop);
extern SA_RETCODE SA_PUBLIC		user_prop(SA_CTX *sactx, SA_CONN *saconn,
									SA_PARAMS *saparams, SA_INT *infop);

/*
** FTP Connect
*/
extern SA_RETCODE SA_EXPORT		ftp_connect(SA_CTX *sactx, SA_CHAR *user,
									SA_INT userlen, SA_CHAR *passwd, 
									SA_INT passwdlen, SA_FTP *ftp);

#if defined(__cplusplus)
}
#endif /* defined(__cplusplus) */

#endif /* __LOGIN_H__ */
